@@ -31,21 +31,6 @@
 #include "gpm-kbd-backlight.h"
 #include "gsd-media-keys-window.h"
 
-static const gchar *kbd_backlight_introspection = ""
-"<?xml version=\"1.0\" encoding=\"UTF-8\"?>""<node name=\"/\">"
-  "<interface name=\"org.mate.PowerManager.Backlight\">"
-    "<method name=\"GetBrightness\">"
-      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"out\"/>"
-    "</method>"
-    "<method name=\"SetBrightness\">"
-      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"in\"/>"
-    "</method>"
-    "<signal name=\"BrightnessChanged\">"
-      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"out\"/>"
-    "</signal>"
-  "</interface>"
-"</node>";
-
 #define GPM_KBD_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_KBD_BACKLIGHT, GpmKbdBacklightPrivate))
 
 struct GpmKbdBacklightPrivate
@@ -53,7 +38,6 @@ struct GpmKbdBacklightPrivate
     UpClient        *client;
     GpmButton       *button;
     GSettings       *settings;
-    GSettings       *settings_gsd;
     GpmControl      *control;
     GpmIdle         *idle;
     gboolean         can_dim;
@@ -433,40 +417,6 @@ gpm_kbd_backlight_dbus_property_set (GDBusConnection *connection,
    return FALSE;
 }
 
-/**
- * gpm_kbd_backlight_register_dbus:
- * @backlight:
- * @connection:
- * @error:
- **/
-void
-gpm_kbd_backlight_register_dbus (GpmKbdBacklight *backlight,
-                GDBusConnection *connection,
-                GError **error)
-{
-   GDBusNodeInfo *node_info;
-   GDBusInterfaceInfo *interface_info;
-   GDBusInterfaceVTable interface_vtable = {
-           gpm_kbd_backlight_dbus_method_call,
-           gpm_kbd_backlight_dbus_property_get,
-           gpm_kbd_backlight_dbus_property_set
-   };
-
-   node_info = g_dbus_node_info_new_for_xml (kbd_backlight_introspection, NULL);
-   interface_info = g_dbus_node_info_lookup_interface (node_info, GPM_DBUS_INTERFACE_BACKLIGHT);
-
-   backlight->priv->bus_connection = g_object_ref (connection);
-   backlight->priv->bus_object_id =
-       g_dbus_connection_register_object (connection,
-                          GPM_DBUS_PATH_KBD_BACKLIGHT,
-                          interface_info,
-                          &interface_vtable,
-                          backlight,
-                          NULL,
-                          error);
-   g_dbus_node_info_unref (node_info);
-}
-
 static gboolean
 gpm_kbd_backlight_evaluate_power_source_and_set (GpmKbdBacklight *backlight)
 {
@@ -626,8 +576,6 @@ gpm_kbd_backlight_idle_changed_cb (GpmIdle *idle,
                  &on_battery,
                  NULL);
 
-    //These were all "settings_gsd" originally
-
    enable_action = on_battery
        ? g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_BATT)
        : g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_AC);
@@ -686,7 +634,6 @@ gpm_kbd_backlight_finalize (GObject *object)
 
    g_object_unref (backlight->priv->control);
    g_object_unref (backlight->priv->settings);
-   //g_object_unref (backlight->priv->settings_gsd);
    g_object_unref (backlight->priv->client);
    g_object_unref (backlight->priv->button);
    g_object_unref (backlight->priv->idle);
@@ -815,10 +762,7 @@ noerr:
              G_CALLBACK (gpm_kbd_backlight_client_changed_cb), backlight);
 #endif
 
-    backlight->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
-	//g_signal_connect (backlight->priv->settings, "changed", G_CALLBACK (gpm_settings_key_changed_cb), backlight);
-   
-    //backlight->priv->settings_gsd = g_settings_new (GSD_SETTINGS_SCHEMA);
+   backlight->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
    /* watch for kbd brightness up and down button presses */
    backlight->priv->button = gpm_button_new ();
@@ -830,14 +774,13 @@ noerr:
              G_CALLBACK (gpm_kbd_backlight_idle_changed_cb), backlight);
 
     /* use a visual widget */
-	backlight->priv->popup = msd_media_keys_window_new ();
-	msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
-						 "gpm-brightness-kbd", TRUE);
-        gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
+   backlight->priv->popup = msd_media_keys_window_new ();
+   msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
+                                            "gpm-brightness-kbd", TRUE);
+   gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
 
    /* since gpm is just starting we can pretty safely assume that we're not idle */
    backlight->priv->system_is_idle = FALSE;
-    //This was settings_gsd originally
    backlight->priv->idle_dim_timeout = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_TIME);
    gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 
