@@ -1182,11 +1182,34 @@ gpm_stats_window_activated_cb (EggUnique *egg_unique, gpointer data)
 	gtk_window_present (GTK_WINDOW (widget));
 }
 
+/**
+ * gpm_stats_device_changed_cb:
+ **/
+static void
+#if UP_CHECK_VERSION(0, 99, 0)
+gpm_stats_device_changed_cb (UpDevice *device, GParamSpec *pspec, gpointer user_data)
+#else
+gpm_stats_device_changed_cb (UpClient *client, UpDevice *device, gpointer user_data)
+#endif
+{
+	const gchar *object_path;
+	object_path = up_device_get_object_path (device);
+	if (object_path == NULL || current_device == NULL)
+		return;
+	egg_debug ("changed:   %s", object_path);
+	if (g_strcmp0 (current_device, object_path) == 0)
+		gpm_stats_update_info_data (device);
+}
+
 /**
  * gpm_stats_add_device:
  **/
 static void
+#if UP_CHECK_VERSION(0, 99, 0)
+gpm_stats_add_device (UpDevice *device, GPtrArray *devices)
+#else
 gpm_stats_add_device (UpDevice *device)
+#endif
 {
 	const gchar *id;
 	GtkTreeIter iter;
@@ -1194,6 +1217,14 @@ gpm_stats_add_device (UpDevice *device)
 	const gchar *icon;
 	UpDeviceKind kind;
 
+#if UP_CHECK_VERSION(0, 99, 0)
+	if (devices != NULL)
+		g_ptr_array_add (devices, device);
+
+	g_signal_connect (device, "notify",
+	                  G_CALLBACK (gpm_stats_device_changed_cb), NULL);
+#endif
+
 	/* get device properties */
 	g_object_get (device,
 		      "kind", &kind,
@@ -1224,48 +1255,51 @@ gpm_stats_data_changed_cb (UpClient *client, gpointer user_data)
  * gpm_stats_device_added_cb:
  **/
 static void
+#if UP_CHECK_VERSION(0, 99, 0)
+gpm_stats_device_added_cb (UpClient *client, UpDevice *device, GPtrArray *devices)
+#else
 gpm_stats_device_added_cb (UpClient *client, UpDevice *device, gpointer user_data)
+#endif
 {
 	const gchar *object_path;
 	object_path = up_device_get_object_path (device);
 	egg_debug ("added:     %s", object_path);
-	gpm_stats_add_device (device);
-}
 
-/**
- * gpm_stats_device_changed_cb:
- **/
-static void
 #if UP_CHECK_VERSION(0, 99, 0)
-gpm_stats_device_changed_cb (UpClient *client, GParamSpec *pspec, gpointer user_data)
-{
-	gpm_stats_button_update_ui();
-}
+	gpm_stats_add_device (device, devices);
 #else
-gpm_stats_device_changed_cb (UpClient *client, UpDevice *device, gpointer user_data)
-{
-	const gchar *object_path;
-	object_path = up_device_get_object_path (device);
-	if (object_path == NULL || current_device == NULL)
-		return;
-	egg_debug ("changed:   %s", object_path);
-	if (g_strcmp0 (current_device, object_path) == 0)
-		gpm_stats_update_info_data (device);
-}
+	gpm_stats_add_device (device);
 #endif
+}
 
 /**
  * gpm_stats_device_removed_cb:
  **/
 static void
+#if UP_CHECK_VERSION(0, 99, 0)
+gpm_stats_device_removed_cb (UpClient *client, const gchar *object_path, GPtrArray *devices)
+#else
 gpm_stats_device_removed_cb (UpClient *client, UpDevice *device, gpointer user_data)
+#endif
 {
-	const gchar *object_path;
 	GtkTreeIter iter;
 	gchar *id = NULL;
 	gboolean ret;
 
-	object_path = up_device_get_object_path (device);
+#if UP_CHECK_VERSION(0, 99, 0)
+	UpDevice *device_tmp;
+	guint i;
+
+	for (i = 0; i < devices->len; i++) {
+		device_tmp = g_ptr_array_index (devices, i);
+		if (g_strcmp0 (up_device_get_object_path (device_tmp), object_path) == 0) {
+			g_ptr_array_remove_index_fast (devices, i);
+			break;
+		}
+	}
+#else
+	const gchar *object_path = up_device_get_object_path (device);
+#endif
 	egg_debug ("removed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0) {
 		gtk_list_store_clear (list_store_info);
@@ -1469,31 +1503,6 @@ gpm_stats_points_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 	gpm_stats_button_update_ui ();
 }
 
-/**
- * gpm_stats_set_combo_simple_text:
- **/
-static void
-gpm_stats_set_combo_simple_text (GtkWidget *combo_box)
-{
-	#if GTK_CHECK_VERSION (2, 24, 0)
-		// nothing to do with GTK_COMBO_BOX_TEXT
-		return;
-	#else
-		GtkCellRenderer *cell;
-		GtkListStore *store;
-
-		store = gtk_list_store_new (1, G_TYPE_STRING);
-		gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
-		g_object_unref (store);
-
-		cell = gtk_cell_renderer_text_new ();
-		gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
-		gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
-						"text", 0,
-						NULL);
-	#endif
-}
-
 /**
  * gpm_stats_highlight_device:
  **/
@@ -1545,7 +1554,7 @@ main (int argc, char *argv[])
 	EggUnique *egg_unique;
 	gboolean ret;
 	UpClient *client;
-	GPtrArray *devices;
+	GPtrArray *devices = NULL;
 	UpDevice *device;
 	UpDeviceKind kind;
 	guint i, j;
@@ -1571,14 +1580,7 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-#if !GLIB_CHECK_VERSION(2,32,0)
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
-#endif
 	dbus_g_thread_init ();
-#if !GLIB_CHECK_VERSION(2,36,0)
-	g_type_init ();
-#endif
 
 	context = g_option_context_new (NULL);
 	/* TRANSLATORS: the program name */
@@ -1607,16 +1609,10 @@ main (int argc, char *argv[])
 
 	/* get UI */
 	builder = gtk_builder_new ();
+	retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics.ui", &error);
 
-	#if GTK_CHECK_VERSION (2, 24, 0)
-		retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics.ui", &error);
-	#else
-		retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics-deprecated.ui", &error);
-	#endif
-
-	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
+	if (error) {
+		egg_error ("failed to load ui: %s", error->message);
 	}
 
 	/* add history graph */
@@ -1727,18 +1723,10 @@ main (int argc, char *argv[])
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_history_type"));
-	gpm_stats_set_combo_simple_text (widget);
-	#if GTK_CHECK_VERSION (2, 24, 0)
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_RATE_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_CHARGE_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_FULL_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_EMPTY_TEXT);
-	#else
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_RATE_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_CHARGE_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_TIME_FULL_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_TIME_EMPTY_TEXT);
-	#endif
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_RATE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_CHARGE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_FULL_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_TIME_EMPTY_TEXT);
 	if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	else
@@ -1747,18 +1735,10 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_history_type_combo_changed_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_stats_type"));
-	gpm_stats_set_combo_simple_text (widget);
-	#if GTK_CHECK_VERSION (2, 24, 0)
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_DATA_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_ACCURACY_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_DATA_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_ACCURACY_TEXT);
-	#else
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_CHARGE_DATA_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_CHARGE_ACCURACY_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_DISCHARGE_DATA_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_STATS_DISCHARGE_ACCURACY_TEXT);
-	#endif
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_DATA_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_CHARGE_ACCURACY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_DATA_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_STATS_DISCHARGE_ACCURACY_TEXT);
 	if (g_strcmp0 (stats_type, GPM_STATS_CHARGE_DATA_VALUE) == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	else if (g_strcmp0 (stats_type, GPM_STATS_CHARGE_DATA_VALUE) == 0)
@@ -1773,20 +1753,11 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_type_combo_changed_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_history_time"));
-	gpm_stats_set_combo_simple_text (widget);
-	#if GTK_CHECK_VERSION (2, 24, 0)
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_MINUTE_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOUR_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOURS_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_DAY_TEXT);
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_WEEK_TEXT);
-	#else
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_MINUTE_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_HOUR_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_HOURS_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_DAY_TEXT);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), GPM_HISTORY_WEEK_TEXT);
-	#endif
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_MINUTE_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOUR_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_HOURS_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_DAY_TEXT);
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), GPM_HISTORY_WEEK_TEXT);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 1);
 	if (history_time == GPM_HISTORY_MINUTE_VALUE)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
@@ -1815,16 +1786,24 @@ main (int argc, char *argv[])
 			device = g_ptr_array_index (devices, i);
 			g_object_get (device, "kind", &kind, NULL);
 			if (kind == j)
+#if UP_CHECK_VERSION(0, 99, 0)
+				/* NULL == do not add it to ptr array */
+				gpm_stats_add_device (device, NULL);
+#else
 				gpm_stats_add_device (device);
+#endif
 		}
 	}
 
 	/* connect now the coldplug is done */
+#if UP_CHECK_VERSION(0, 99, 0)
+	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), devices);
+	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), devices);
+#else
 	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
 	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
-#if UP_CHECK_VERSION(0, 99, 0)
-	g_signal_connect (client, "notify", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
-#else
+#endif
+#if !UP_CHECK_VERSION(0, 99, 0)
 	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
 #endif
 
@@ -1854,8 +1833,6 @@ main (int argc, char *argv[])
 	if (last_device != NULL)
 		gpm_stats_highlight_device (last_device);
 
-	g_ptr_array_unref (devices);
-
 	/* set axis */
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_history_type"));
 	gpm_stats_history_type_combo_changed_cb (widget, NULL);
@@ -1869,6 +1846,9 @@ main (int argc, char *argv[])
 #if !UP_CHECK_VERSION(0, 99, 0)
 out:
 #endif
+	if (devices != NULL)
+		g_ptr_array_unref (devices);
+
 	g_object_unref (settings);
 	g_object_unref (client);
 	g_object_unref (wakeups);
