@@ -39,6 +39,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libupower-glib/upower.h>
+#include <libmate-desktop/mate-aboutdialog.h>
 
 #include "egg-debug.h"
 
@@ -94,11 +95,8 @@ gpm_tray_icon_set_tooltip (GpmTrayIcon *icon, const gchar *tooltip)
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 	g_return_val_if_fail (tooltip != NULL, FALSE);
 
-#if GTK_CHECK_VERSION(2,15,0)
 	gtk_status_icon_set_tooltip_text (icon->priv->status_icon, tooltip);
-#else
-	gtk_status_icon_set_tooltip (icon->priv->status_icon, tooltip);
-#endif
+
 	return TRUE;
 }
 
@@ -169,6 +167,37 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
+/**
+ * gpm_tray_icon_show_about_cb:
+ * @action: A valid GtkAction
+ **/
+static void
+gpm_tray_icon_show_about_cb (GtkMenuItem *item, gpointer data)
+{
+	const gchar *authors[] =
+	{
+		"Perberos",
+		"Steve Zesch",
+		"Stefano Karapetsas",
+		NULL
+	};
+
+	mate_show_about_dialog (NULL,
+							"program-name", _("Power Manager"),
+							"version", VERSION,
+							"comments", _("Power management daemon"),
+							"copyright", _("Copyright \xC2\xA9 2011-2014 MATE developers"),
+							"authors", authors,
+							/* Translators should localize the following string
+							* which will be displayed at the bottom of the about
+							* box to give credit to the translator(s).
+							*/
+							"translator-credits", _("translator-credits"),
+							"logo-icon-name", "mate-power-manager",
+							"website", "http://www.mate-desktop.org",
+							NULL);
+}
+
 /**
  * gpm_tray_icon_popup_cleared_cd:
  * @widget: The popup Gtkwidget
@@ -275,11 +304,9 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon, guint32 timestamp)
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_KEYBOARD);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_PDA);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_PHONE);
-#if UP_CHECK_VERSION(0,9,5)
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_MEDIA_PLAYER);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_TABLET);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_COMPUTER);
-#endif
 	g_ptr_array_unref (array);
 
 	/* skip for things like live-cd's and GDM */
@@ -300,6 +327,12 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon, guint32 timestamp)
 			  G_CALLBACK (gpm_tray_icon_show_preferences_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
+	/* about */
+	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_ABOUT, NULL);
+	g_signal_connect (G_OBJECT (item), "activate",
+			  G_CALLBACK (gpm_tray_icon_show_about_cb), icon);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
 skip_prefs:
 	/* show the menu */
 	gtk_widget_show_all (GTK_WIDGET (menu));
